/**
 * Copyright (c) 2024 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "frame.h"
#include "display/symbol.h"
#include "rpg/world/map.h"
#include "game/game.h"
#include "ui/textbox.h"

#include "display/draw/drawshape.h"
#include "display/draw/drawui.h"
#include "display/draw/drawtext.h"
#include "display/draw/drawmap.h"

char_t FRAME_BUFFER[FRAME_HEIGHT * FRAME_WIDTH];
uint8_t FRAME_COLOR[FRAME_HEIGHT * FRAME_WIDTH];

void frameInit() {
  drawClear(' ', COLOR_BLACK);
}

void frameUpdate() {
  switch(GAME.state) {
    case GAME_STATE_PAUSED:

  }

  map_t *map = GAME.currentMap;
  if(map == NULL) return;

  // Try get player
  entity_t *player = mapEntityGetByType(map, ENTITY_TYPE_PLAYER);
  uint16_t cameraPositionX, cameraPositionY;
  if(player == NULL) {
    cameraPositionX = 0;
    cameraPositionY = 0;
  } else {
    cameraPositionX = player->x;
    cameraPositionY = player->y;
  }

  drawMap(
    GAME.currentMap,
    cameraPositionX, cameraPositionY,
    0, 0,
    FRAME_WIDTH, FRAME_HEIGHT
  );
}